==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/YearlyRetentionScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.MonthOfYear
import com.pulumi.azurenative.workloads.kotlin.enums.RetentionScheduleFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Yearly retention schedule.
 * @property monthsOfYear List of months of year of yearly retention policy.
 * @property retentionDuration Retention duration of retention Policy.
 * @property retentionScheduleDaily Daily retention format for yearly retention policy.
 * @property retentionScheduleFormatType Retention schedule format for yearly retention policy.
 * @property retentionScheduleWeekly Weekly retention format for yearly retention policy.
 * @property retentionTimes Retention times of retention policy.
 */
public data class YearlyRetentionScheduleArgs(
    public val monthsOfYear: Output<List<MonthOfYear>>? = null,
    public val retentionDuration: Output<RetentionDurationArgs>? = null,
    public val retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null,
    public val retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null,
    public val retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null,
    public val retentionTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs.builder()
            .monthsOfYear(
                monthsOfYear?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .retentionDuration(retentionDuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionScheduleDaily(
                retentionScheduleDaily?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionScheduleFormatType(
                retentionScheduleFormatType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .retentionScheduleWeekly(
                retentionScheduleWeekly?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionTimes(retentionTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [YearlyRetentionScheduleArgs].
 */
@PulumiTagMarker
public class YearlyRetentionScheduleArgsBuilder internal constructor() {
    private var monthsOfYear: Output<List<MonthOfYear>>? = null

    private var retentionDuration: Output<RetentionDurationArgs>? = null

    private var retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null

    private var retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null

    private var retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null

    private var retentionTimes: Output<List<String>>? = null

    /**
     * @param value List of months of year of yearly retention policy.
     */
    @JvmName("ilamyepwnherfahp")
    public suspend fun monthsOfYear(`value`: Output<List<MonthOfYear>>) {
        this.monthsOfYear = value
    }

    @JvmName("fdvykvwylghptljj")
    public suspend fun monthsOfYear(vararg values: Output<MonthOfYear>) {
        this.monthsOfYear = Output.all(values.asList())
    }

    /**
     * @param values List of months of year of yearly retention policy.
     */
    @JvmName("plskroihpbggvbpu")
    public suspend fun monthsOfYear(values: List<Output<MonthOfYear>>) {
        this.monthsOfYear = Output.all(values)
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("amtpiaryxivnelub")
    public suspend fun retentionDuration(`value`: Output<RetentionDurationArgs>) {
        this.retentionDuration = value
    }

    /**
     * @param value Daily retention format for yearly retention policy.
     */
    @JvmName("ywstgyugeoennfoy")
    public suspend fun retentionScheduleDaily(`value`: Output<DailyRetentionFormatArgs>) {
        this.retentionScheduleDaily = value
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("ynwkitdgkoopupfa")
    public suspend
    fun retentionScheduleFormatType(`value`: Output<Either<String, RetentionScheduleFormat>>) {
        this.retentionScheduleFormatType = value
    }

    /**
     * @param value Weekly retention format for yearly retention policy.
     */
    @JvmName("gdxbdmgfyjxjvqei")
    public suspend fun retentionScheduleWeekly(`value`: Output<WeeklyRetentionFormatArgs>) {
        this.retentionScheduleWeekly = value
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("uvfnskvmeanejupd")
    public suspend fun retentionTimes(`value`: Output<List<String>>) {
        this.retentionTimes = value
    }

    @JvmName("cprlfioocsbibfou")
    public suspend fun retentionTimes(vararg values: Output<String>) {
        this.retentionTimes = Output.all(values.asList())
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("dvgvryfhxjgglikw")
    public suspend fun retentionTimes(values: List<Output<String>>) {
        this.retentionTimes = Output.all(values)
    }

    /**
     * @param value List of months of year of yearly retention policy.
     */
    @JvmName("yplpfglawdcqlbmn")
    public suspend fun monthsOfYear(`value`: List<MonthOfYear>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthsOfYear = mapped
    }

    /**
     * @param values List of months of year of yearly retention policy.
     */
    @JvmName("joorhjsvqulpnjww")
    public suspend fun monthsOfYear(vararg values: MonthOfYear) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthsOfYear = mapped
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("lafvtsxoegqulxbx")
    public suspend fun retentionDuration(`value`: RetentionDurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionDuration = mapped
    }

    /**
     * @param argument Retention duration of retention Policy.
     */
    @JvmName("gdhjsjfdibfwuegq")
    public suspend fun retentionDuration(argument: suspend RetentionDurationArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionDurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionDuration = mapped
    }

    /**
     * @param value Daily retention format for yearly retention policy.
     */
    @JvmName("ybctvwlojgjqklek")
    public suspend fun retentionScheduleDaily(`value`: DailyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param argument Daily retention format for yearly retention policy.
     */
    @JvmName("evjtbmsspuroraxv")
    public suspend
    fun retentionScheduleDaily(argument: suspend DailyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("gsgmtmfupxsboetw")
    public suspend
    fun retentionScheduleFormatType(`value`: Either<String, RetentionScheduleFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("dvkglnhmdphqlruj")
    public fun retentionScheduleFormatType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("xlwfvdtneafwmcfd")
    public fun retentionScheduleFormatType(`value`: RetentionScheduleFormat) {
        val toBeMapped = Either.ofRight<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Weekly retention format for yearly retention policy.
     */
    @JvmName("ffsrdqsbdisyoblr")
    public suspend fun retentionScheduleWeekly(`value`: WeeklyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param argument Weekly retention format for yearly retention policy.
     */
    @JvmName("ugjxrixumvewatwl")
    public suspend
    fun retentionScheduleWeekly(argument: suspend WeeklyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("bevpfjttkyoihjma")
    public suspend fun retentionTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("soedefciisjynscd")
    public suspend fun retentionTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    internal fun build(): YearlyRetentionScheduleArgs = YearlyRetentionScheduleArgs(
        monthsOfYear = monthsOfYear,
        retentionDuration = retentionDuration,
        retentionScheduleDaily = retentionScheduleDaily,
        retentionScheduleFormatType = retentionScheduleFormatType,
        retentionScheduleWeekly = retentionScheduleWeekly,
        retentionTimes = retentionTimes,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/workloads/kotlin/inputs/YearlyRetentionScheduleArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.workloads.kotlin.inputs

import com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs.builder
import com.pulumi.azurenative.workloads.kotlin.enums.MonthOfYear
import com.pulumi.azurenative.workloads.kotlin.enums.RetentionScheduleFormat
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Yearly retention schedule.
 * @property monthsOfYear List of months of year of yearly retention policy.
 * @property retentionDuration Retention duration of retention Policy.
 * @property retentionScheduleDaily Daily retention format for yearly retention policy.
 * @property retentionScheduleFormatType Retention schedule format for yearly retention policy.
 * @property retentionScheduleWeekly Weekly retention format for yearly retention policy.
 * @property retentionTimes Retention times of retention policy.
 */
public data class YearlyRetentionScheduleArgs(
    public val monthsOfYear: Output<List<MonthOfYear>>? = null,
    public val retentionDuration: Output<RetentionDurationArgs>? = null,
    public val retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null,
    public val retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null,
    public val retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null,
    public val retentionTimes: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs> {
    override fun toJava(): com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs =
        com.pulumi.azurenative.workloads.inputs.YearlyRetentionScheduleArgs.builder()
            .monthsOfYear(
                monthsOfYear?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .retentionDuration(retentionDuration?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .retentionScheduleDaily(
                retentionScheduleDaily?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionScheduleFormatType(
                retentionScheduleFormatType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .retentionScheduleWeekly(
                retentionScheduleWeekly?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .retentionTimes(retentionTimes?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [YearlyRetentionScheduleArgs].
 */
@PulumiTagMarker
public class YearlyRetentionScheduleArgsBuilder internal constructor() {
    private var monthsOfYear: Output<List<MonthOfYear>>? = null

    private var retentionDuration: Output<RetentionDurationArgs>? = null

    private var retentionScheduleDaily: Output<DailyRetentionFormatArgs>? = null

    private var retentionScheduleFormatType: Output<Either<String, RetentionScheduleFormat>>? = null

    private var retentionScheduleWeekly: Output<WeeklyRetentionFormatArgs>? = null

    private var retentionTimes: Output<List<String>>? = null

    /**
     * @param value List of months of year of yearly retention policy.
     */
    @JvmName("neblslpklpdoqmsn")
    public suspend fun monthsOfYear(`value`: Output<List<MonthOfYear>>) {
        this.monthsOfYear = value
    }

    @JvmName("ntedckfquulmugkb")
    public suspend fun monthsOfYear(vararg values: Output<MonthOfYear>) {
        this.monthsOfYear = Output.all(values.asList())
    }

    /**
     * @param values List of months of year of yearly retention policy.
     */
    @JvmName("hflvkscppfgqqiyk")
    public suspend fun monthsOfYear(values: List<Output<MonthOfYear>>) {
        this.monthsOfYear = Output.all(values)
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("yjfummnillhcbksj")
    public suspend fun retentionDuration(`value`: Output<RetentionDurationArgs>) {
        this.retentionDuration = value
    }

    /**
     * @param value Daily retention format for yearly retention policy.
     */
    @JvmName("sdemomdodedsfini")
    public suspend fun retentionScheduleDaily(`value`: Output<DailyRetentionFormatArgs>) {
        this.retentionScheduleDaily = value
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("irmucrmthnsxswvj")
    public suspend
    fun retentionScheduleFormatType(`value`: Output<Either<String, RetentionScheduleFormat>>) {
        this.retentionScheduleFormatType = value
    }

    /**
     * @param value Weekly retention format for yearly retention policy.
     */
    @JvmName("icokcaemjjelygsa")
    public suspend fun retentionScheduleWeekly(`value`: Output<WeeklyRetentionFormatArgs>) {
        this.retentionScheduleWeekly = value
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("lamelbgxxuypwylu")
    public suspend fun retentionTimes(`value`: Output<List<String>>) {
        this.retentionTimes = value
    }

    @JvmName("iqxkphggkbyqmmct")
    public suspend fun retentionTimes(vararg values: Output<String>) {
        this.retentionTimes = Output.all(values.asList())
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("uuptdgigbdrklicj")
    public suspend fun retentionTimes(values: List<Output<String>>) {
        this.retentionTimes = Output.all(values)
    }

    /**
     * @param value List of months of year of yearly retention policy.
     */
    @JvmName("yowrdbxswmmpykoq")
    public suspend fun monthsOfYear(`value`: List<MonthOfYear>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.monthsOfYear = mapped
    }

    /**
     * @param values List of months of year of yearly retention policy.
     */
    @JvmName("aakeqdcnunkfsogo")
    public suspend fun monthsOfYear(vararg values: MonthOfYear) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.monthsOfYear = mapped
    }

    /**
     * @param value Retention duration of retention Policy.
     */
    @JvmName("fhldkwhjwdjhkcba")
    public suspend fun retentionDuration(`value`: RetentionDurationArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionDuration = mapped
    }

    /**
     * @param argument Retention duration of retention Policy.
     */
    @JvmName("mttecvxyrpjajwjg")
    public suspend fun retentionDuration(argument: suspend RetentionDurationArgsBuilder.() -> Unit) {
        val toBeMapped = RetentionDurationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionDuration = mapped
    }

    /**
     * @param value Daily retention format for yearly retention policy.
     */
    @JvmName("mqdpeboxheranbfs")
    public suspend fun retentionScheduleDaily(`value`: DailyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param argument Daily retention format for yearly retention policy.
     */
    @JvmName("oyibcqlyvbfhgxej")
    public suspend
    fun retentionScheduleDaily(argument: suspend DailyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = DailyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleDaily = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("vbirjamfghbtgqgd")
    public suspend
    fun retentionScheduleFormatType(`value`: Either<String, RetentionScheduleFormat>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("vsmifeyjxdfltkgt")
    public fun retentionScheduleFormatType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Retention schedule format for yearly retention policy.
     */
    @JvmName("lhqyfgfnmapaoooj")
    public fun retentionScheduleFormatType(`value`: RetentionScheduleFormat) {
        val toBeMapped = Either.ofRight<String, RetentionScheduleFormat>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionScheduleFormatType = mapped
    }

    /**
     * @param value Weekly retention format for yearly retention policy.
     */
    @JvmName("yfdtbgvstblxgbev")
    public suspend fun retentionScheduleWeekly(`value`: WeeklyRetentionFormatArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param argument Weekly retention format for yearly retention policy.
     */
    @JvmName("brylkqejkmphcadt")
    public suspend
    fun retentionScheduleWeekly(argument: suspend WeeklyRetentionFormatArgsBuilder.() -> Unit) {
        val toBeMapped = WeeklyRetentionFormatArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.retentionScheduleWeekly = mapped
    }

    /**
     * @param value Retention times of retention policy.
     */
    @JvmName("stnsrgwhagkdolms")
    public suspend fun retentionTimes(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    /**
     * @param values Retention times of retention policy.
     */
    @JvmName("cnnjqflogltjqxpm")
    public suspend fun retentionTimes(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.retentionTimes = mapped
    }

    internal fun build(): YearlyRetentionScheduleArgs = YearlyRetentionScheduleArgs(
        monthsOfYear = monthsOfYear,
        retentionDuration = retentionDuration,
        retentionScheduleDaily = retentionScheduleDaily,
        retentionScheduleFormatType = retentionScheduleFormatType,
        retentionScheduleWeekly = retentionScheduleWeekly,
        retentionTimes = retentionTimes,
    )
}
